;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "gruvbox-theme" "20250117.222"
  "A retro-groove colour theme for Emacs."
  '((autothemer "0.2"))
  :url "https://github.com/greduan/emacs-theme-gruvbox"
  :commit "6cbf80b6cde3c2390502dc94a911ab7378495249"
  :revdesc "6cbf80b6cde3"
  :authors '(("Jason Milkins" . "jasonm23@gmail.com"))
  :maintainers '(("Jason Milkins" . "jasonm23@gmail.com")))
